<?php
/**
 * dici Theme Customizer
 *
 * @package dici
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function chromium_dir_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'chromium_dir_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'chromium_dir_customize_partial_blogdescription',
		) );
	}
}
add_action( 'customize_register', 'chromium_dir_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function chromium_dir_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function chromium_dir_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function chromium_dir_customize_preview_js() {
	wp_enqueue_script( 'chromium-dir-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'chromium_dir_customize_preview_js' );


/**
 * Customizer options based on Kirki Plugin.
 */

// Add Kirki Fallback class
require get_template_directory() . '/inc/lib/class-kirki-fallback.php';

if ( class_exists( 'Chromium_Dir_Kirki_Customizer' ) ) : // Chromium_Dir_Kirki_Customizer Options Start

	Chromium_Dir_Kirki_Customizer::add_config( 'chromium_dir_theme', array(
		'option_type' => 'theme_mod',
		'capability'  => 'edit_theme_options',
        'gutenberg_support' => true,
	) );

	if ( ! function_exists('chromium_dir_add_custom_fonts') ) {

		function chromium_dir_add_custom_fonts( $fonts ){

			return $fonts;
		}

	}

	add_filter( 'kirki_fonts_standard_fonts', 'chromium_dir_add_custom_fonts' );

// Available Section

// Typography Section
	Chromium_Dir_Kirki_Customizer::add_section( 'typography', array(
		'title'      => esc_html__( 'Typography', 'chromium-dir' ),
		'priority'   => 1,
		'capability' => 'edit_theme_options',
	) );

// Header Section
	Chromium_Dir_Kirki_Customizer::add_section( 'header', array(
		'title'      => esc_html__( 'Header Layout', 'chromium-dir' ),
		'priority'   => 2,
		'capability' => 'edit_theme_options',
	) );

// Layout Section
	Chromium_Dir_Kirki_Customizer::add_section( 'layout', array(
		'title'      => esc_html__( 'Theme Layout', 'chromium-dir' ),
		'priority'   => 3,
		'capability' => 'edit_theme_options',
	) );

// Footer Section
	Chromium_Dir_Kirki_Customizer::add_section( 'footer', array(
		'title'      => esc_html__( 'Footer Layout', 'chromium-dir' ),
		'priority'   => 4,
		'capability' => 'edit_theme_options',
	) );

// Blog Section
	Chromium_Dir_Kirki_Customizer::add_section( 'blog', array(
		'title'      => esc_html__( 'Blog Options', 'chromium-dir' ),
		'priority'   => 5,
		'capability' => 'edit_theme_options'
	) );

// Post Section
	Chromium_Dir_Kirki_Customizer::add_section( 'post', array(
		'title'      => esc_html__( 'Post Options', 'chromium-dir' ),
		'priority'   => 5,
		'capability' => 'edit_theme_options',
	) );

// Shop Section
	Chromium_Dir_Kirki_Customizer::add_section( 'shop', array(
		'title'      => esc_html__( 'Shop Page Options', 'chromium-dir' ),
		'priority'   => 5,
		'capability' => 'edit_theme_options',
	) );

// Product Section
	Chromium_Dir_Kirki_Customizer::add_section( 'product', array(
		'title'      => esc_html__( 'Product Page Options', 'chromium-dir' ),
		'priority'   => 5,
		'capability' => 'edit_theme_options'
	) );

// Listings Section
    Chromium_Dir_Kirki_Customizer::add_section( 'listings', array(
        'title'      => esc_html__( 'Listings Page Options', 'chromium-dir' ),
        'priority'   => 5,
        'capability' => 'edit_theme_options'
    ) );

// Typography Start
	// global typography start
	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'typography',
		'settings'    => 'global_font',
		'label'       => esc_html__( 'Global Font', 'chromium-dir' ),
		'description' => esc_attr__( 'Site wide font used everywhere if no other setting applied.', 'chromium-dir' ),
		'section'     => 'typography',
        'default'     => array(
            'font-family'    => 'Roboto',
            'variant'        => 'regular',
            'font-weight'    => '400',
            'font-size'      => '15px',
            'line-height'    => '1.5',
            'letter-spacing' => '0',
            'color'          => '#262626',
            'text-transform' => 'none',
            'text-align'     => 'left',
            'subsets' => array( 'latin-ext' ),
        ),
        'priority'    => 1,
        'output'      => array(
            array(
                'element' => array(
                    'body'
                ),
            ),
            array(
                'element'  => '.edit-post-visual-editor.editor-styles-wrapper',
                'context'  => array( 'editor' ),
            ),
        ),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'typography',
		'settings'    => 'headings_font',
		'label'       => esc_html__( 'Headings Font', 'chromium-dir' ),
		'description' => esc_attr__( 'Site wide headings font used everywhere if no other setting applied.', 'chromium-dir' ),
		'section'     => 'typography',
		'default'     => array(
			'font-family'    => 'Roboto',
			'color'          => '#000000',
            'line-height'    => '1.3',
            'subsets' => array( 'latin-ext' ),
		),
		'priority'    => 2,
		'output'      => array(
			array(
				'element' => array(
					'h1',
					'h2',
					'h3',
					'h4',
					'.chromium-dir-testimonials .elementor-testimonial-content',
					'.tz-woo-product-categories li .cat-caption .cat-name'
				),
			),
            array(
                'element'  => array(
                    '.edit-post-visual-editor.editor-styles-wrapper h1',
                    '.edit-post-visual-editor.editor-styles-wrapper h2',
                    '.edit-post-visual-editor.editor-styles-wrapper h3',
                    '.edit-post-visual-editor.editor-styles-wrapper h4',
                    '.editor-post-title__block',
                    '.editor-post-title__block .editor-post-title__input'
                ),
                'context'  => array( 'editor' ),
            ),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'color',
		'settings'    => 'accent_color',
		'label'       => esc_html__( 'Accent Color', 'chromium-dir' ),
		'description' => esc_attr__( 'Accent Color (secondary site color).', 'chromium-dir' ),
		'section'     => 'typography',
		'default'     => '#ddd',
		'choices'     => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => array(
					'.site-header-cart .cart-toggler .cart-contents',
					'.site-header-cart .product_list_widget li .remove',
					'.tagcloud a:hover',
					'.single-product .summary .product_meta .posted_in:before',
					'.single-product .summary .product_meta .sku_wrapper:before',
					'.single-product .summary .product_meta .tagged_as:before',
					'.vdz_cb_btn',
					'.chromium-dir-call-back-button-view:before, .chromium-dir-shop-address-view:before',
					'ul.products .product .added_to_cart',
                    'blockquote:before'

				),
				'property' => 'color',
			),

			array(
				'element'  => array(
					'.site-header-cart .product_list_widget li .remove:hover',
					'.site-header-cart .widget_shopping_cart_content .buttons a:hover',
					'.widget_product_tag_cloud .tagcloud a:hover',
					'.single-product .product .summary .single_add_to_cart_button:hover',
					'ul.products .product .add_to_cart_button:hover',
					'ul.products .product .product_type_variable:hover',
					'.single-product .single-product-reviews .review-button-cont .button:hover',
					'#review_form #respond p.form-submit input:hover',
					'.heading-undersocre:after',
					'#secondary .widget.widget_tag_cloud .tagcloud a:hover',
					'.mejs-container, .mejs-container .mejs-controls, .mejs-embed, .mejs-embed body',
					'.widget_price_filter .ui-slider .ui-slider-range',
					'.widget_price_filter .price_slider_amount .button:hover',
					'.woo-variation-swatches-stylesheet-enabled .variable-items-wrapper .variable-item.button-variable-item:not(.radio-variable-item).selected',
					'.woo-variation-swatches-stylesheet-enabled .variable-items-wrapper .variable-item.button-variable-item:not(.radio-variable-item).selected:hover',
					'.single-post .rpbt_shortcode > h3:after',
					'.shop_table .button:hover',
					'.wpcf7-form input[type="submit"]:hover',
					'.elementor-widget-tz-woo-product-tabs .tz-tab-title::after'

				),
				'property' => 'background-color',
			),

			array(
				'element' => array(
					'.lrm-form button[type=submit]',
					'.tz-woo-product-categories .owl-dots .owl-dot',
					'.underline:after'
				),
				'property' => 'background-color',
				'suffix'   => '!important',
			),

			array(
				'element'  => array(
					'.widget_product_tag_cloud .tagcloud a:hover',
					'input[type="text"]:focus, input[type="email"]:focus, input[type="url"]:focus, input[type="password"]:focus, input[type="search"]:focus, input[type="number"]:focus, input[type="tel"]:focus, input[type="range"]:focus, input[type="date"]:focus, input[type="month"]:focus, input[type="week"]:focus, input[type="time"]:focus, input[type="datetime"]:focus, input[type="datetime-local"]:focus, input[type="color"]:focus, textarea:focus',
					'.single-product .woocommerce-product-gallery .flex-control-thumbs li img.flex-active, .single-product .woocommerce-product-gallery .flex-control-thumbs li img:hover',
                    'blockquote',
                    '.comment-list .comment-body .comment-content blockquote'
				),
				'property' => 'border-color',
			),

			array(
				'element' => array(
					'.tz-woo-product-categories .owl-prev, .tz-woo-product-categories .owl-next',
					'.tz-posts-carousel .owl-prev, .tz-posts-carousel .owl-next',
				),
				'property' => 'color',
				'suffix'   => '!important',
			)

		),
	) );


	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'color',
		'settings'    => 'accent_color_text',
		'label'       => esc_html__( 'Accent Color for Text', 'chromium-dir' ),
		'description' => esc_attr__( 'Accent Color for Text.', 'chromium-dir' ),
		'section'     => 'typography',
		'default'     => '#009cdd',
		'choices'     => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => array(
					'cite',
					'.widget_product_categories .product-categories li a:hover',
					'#secondary .widget.comments_widget_plus .cwp-author-link',
					'#secondary .widget.recent-posts-widget-with-thumbnails li .rpwwt-post-categories',
					'#secondary .widget.widget_categories li a:hover, #secondary .widget.widget_archive li a:hover',
					'.widget_calendar table #today',
					'.widget_recent_comments .recentcomments .comment-author-link a',
					'.comment-list .comment-body .comment-meta .comment-author .fn a',
					'.page-header-block [class*="crumb"] .breadcrumb_last, .error404 .page-header [class*="crumb"] .breadcrumb_last, .page-header-block [class*="crumb"] .nav-item:last-child',
					'.single-product .summary .product_meta .posted_in a',
					'.single-product .summary .product_meta .tagged_as a',
					'.shop_table.woocommerce-checkout-review-order-table .order-total .amount',
					'.breadcrumb_last',
                    '.entry-categories .cat-links a',
				),
				'property' => 'color',
			),
            array(
                'element'  => array(
                    'cite',
                ),
                'context'  => array( 'editor' ),
            ),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'color',
		'settings'    => 'accent_color_alpha',
		'label'       => esc_html__( 'Accent Color with Alpha', 'chromium-dir' ),
		'description' => esc_attr__( 'Accent Color with Alpha chanel (secondary site color).', 'chromium-dir' ),
		'section'     => 'typography',
		'default'     => '#00d1b7',
		'choices'     => array(
			'alpha' => true,
		),
		'output'   => array(

			array(
				'element'  => array(
					'.mejs-container, .mejs-container .mejs-controls, .mejs-embed, .mejs-embed body',


				),
				'property' => 'background',
			),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'color',
		'settings'    => 'links_color',
		'label'       => esc_html__( 'Links color', 'chromium-dir' ),
		'description' => esc_attr__( 'Color for links site-wide.', 'chromium-dir' ),
		'section'     => 'typography',
		'default'     => '#000000',
		'choices'     => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => 'a',
				'property' => 'color',
			),
            array(
                'element'  => array(
                    'a',
                ),
                'property' => 'color',
                'context'  => array( 'editor' ),
            ),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'color',
		'settings'    => 'links_color_hover',
		'label'       => esc_html__( 'Hovered links color', 'chromium-dir' ),
		'description' => esc_attr__( 'Hover color for links site-wide.', 'chromium-dir' ),
		'section'     => 'typography',
		'default'     => '#7e7e7e',
		'choices'     => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => 'a:hover',
				'property' => 'color',
			),
            array(
                'element'  => array(
                    'a:hover',
                ),
                'property' => 'color',
                'context'  => array( 'editor' ),
            ),
		),
	) );


	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'typography',
		'settings'    => 'menu_font',
		'label'       => esc_html__( 'Menu Font', 'chromium-dir' ),
		'description' => esc_attr__( 'Typography for main menu.', 'chromium-dir' ),
		'section'     => 'typography',
		'default'     => array(
			'font-family'    => 'Roboto',
			'variant'        => '500',
			'font-size'      => '15px',
			'line-height'    => '1.5',
			'letter-spacing' => '0',
			'color'          => '#000000',
			'text-transform' => 'capitalize',
			'text-align'     => 'left',
            'subsets' => array( 'latin-ext' ),
		),
		'priority'    => 10,
		'output'      => array(
			array(
				'element' => array(
					'.main-navigation .menu > li > a',
					'.main-navigation .menu > ul > li > a',
					'.main-navigation .menu .nav-menu > li > a',
                    '#site-navigation ul.mega-menu li.mega-menu-item',
				),
			),
            'suffix' => '!important',
		),

	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'typography',
		'settings'    => 'logo_font',
		'label'       => esc_html__( 'Logo Font', 'chromium-dir' ),
		'description' => esc_attr__( 'Logo font, color, and size.', 'chromium-dir' ),
		'section'     => 'typography',
		'default'     => array(
			'font-family'    => 'Roboto',
			'variant'        => '500',
			'font-size'      => '32px',
			'line-height'    => '1.5',
			'letter-spacing' => '0.5px',
			'color'          => '#000000',
			'text-transform' => 'uppercase',
			'text-align'     => 'center',
            'subsets' => array( 'latin-ext' ),
		),
		'priority'    => 3,
		'output'      => array(
			array(
				'element' => array(
					'.site-title',
					'.chromium-dir-footer-widget-area .footer-title b'

				),
			),
		),
	) );


	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'typography',
		'settings'    => 'page_heading_font',
		'label'       => esc_html__( 'Page Header Font', 'chromium-dir' ),
		'description' => esc_attr__( 'Title font for page header block.', 'chromium-dir' ),
		'section'     => 'typography',
		'default'     => array(
			'font-family'    => 'Roboto',
			'variant'        => '600',
			'font-size'      => '30px',
			'line-height'    => '1.5',
			'letter-spacing' => '0',
			'color'          => '#ffffff',
			'text-transform' => 'uppercase',
			'text-align'     => 'center',
            'subsets' => array( 'latin-ext' ),
		),
		'priority'    => 3,
		'output'      => array(
			array(
				'element' => array(
					'.page-header-block .page-title',
                    '.single-post.chromium-dir-post-modern .page-header-block .entry-title',
				),
			),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'typography',
		'settings'    => 'footer_signature_font',
		'label'       => esc_html__( 'Footer Signature Font', 'chromium-dir' ),
		'description' => esc_attr__( 'Typography for footer signature.', 'chromium-dir' ),
		'section'     => 'typography',
		'default'     => array(
			'font-family'    => 'Roboto',
			'variant'        => 'regular',
			'font-size'      => '12px',
			'line-height'    => '1.5',
			'letter-spacing' => '0',
			'color'          => '#898989',
			'text-transform' => 'normal',
			'text-align'     => 'left',
            'subsets' => array( 'latin-ext' ),
		),
		'priority'    => 20,
		'output'      => array(
			array(
				'element' => array(
					'.site-info',
					'.site-info a',
					'.site-footer .menu li a'

				),
			),
		),
	) );
	// global typography end

	// blog typography start

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'typography',
		'settings'    => 'blog_widget_title',
		'label'       => esc_html__( 'Blog Widget Titles', 'chromium-dir' ),
		'description' => esc_attr__( 'Typography for Sidebar widget title', 'chromium-dir' ),
		'section'     => 'typography',
		'default'     => array(
			'font-family'    => 'Roboto',
			'variant'        => '600',
			'font-size'      => '15px',
			'line-height'    => '1.5',
			'letter-spacing' => '1px',
			'color'          => '#000000',
			'text-transform' => 'uppercase',
			'text-align'     => 'left',
            'subsets' => array( 'latin-ext' ),
		),
		'priority'    => 5,
		'output'      => array(
			array(
				'element' => array(
					'#secondary .widget-title',
				),
			),
		),
	) );

    Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
        'type'        => 'typography',
        'settings'    => 'blog_widget_content',
        'label'       => esc_html__( 'Blog Widget Content', 'chromium-dir' ),
        'description' => esc_attr__( 'Typography for Sidebar widget content', 'chromium-dir' ),
        'section'     => 'typography',
        'default'     => array(
            'font-size'      => '14px',
            'line-height'    => '1.5',
            'color'          => '#262626',
            'text-align'     => 'left',
            'subsets' => array( 'latin-ext' ),
        ),
        'priority'    => 5,
        'output'      => array(
            array(
                'element' => array(
                    '#secondary > *:not(.widget-title)',
                ),
            ),
        ),
    ) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'typography',
		'settings'    => 'archive_post_titles',
		'label'       => esc_html__( 'Blog Post Titles', 'chromium-dir' ),
		'description' => esc_attr__( 'Post titles typography on posts listings.', 'chromium-dir' ),
		'section'     => 'typography',
		'default'     => array(
			'font-family'    => 'Roboto',
			'variant'        => '500',
			'font-size'      => '32px',
			'line-height'    => '1.3',
			'letter-spacing' => '0',
			'color'          => '#000000',
			'text-transform' => 'none',
            'subsets' => array( 'latin-ext' ),
		),
		'priority'    => 5,
		'output'      => array(
			array(
				'element' => array(
					'.blog #content article.post .entry-title',
                    '.search article[class*="post"] .entry-title',
                    '.archive article[class*="post"] .entry-title'

				),
			),
		),
	) );

    Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
        'type'        => 'typography',
        'settings'    => 'blog_post_text',
        'label'       => esc_html__( 'Blog Post Text', 'chromium-dir' ),
        'description' => esc_attr__( 'Typography for Blog Post text', 'chromium-dir' ),
        'section'     => 'typography',
        'default'     => array(
            'font-family'    => 'Roboto',
            'variant'        => '400',
            'font-size'      => '15px',
            'line-height'    => '1.75',
            'letter-spacing' => '0',
            'color'          => '#262626',
            'text-transform' => 'normal',
            'subsets' => array( 'latin-ext' ),
        ),
        'priority'    => 5,
        'output'      => array(
            array(
                'element' => array(
                    '.blog .post .chromium-dir-post-inner .entry-content',

                ),
            ),
        ),
    ) );


	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'typography',
		'settings'    => 'single_post_text',
		'label'       => esc_html__( 'Single Post Text', 'chromium-dir' ),
		'description' => esc_attr__( 'Typography for Blog Post text', 'chromium-dir' ),
		'section'     => 'typography',
		'default'     => array(
			'font-family'    => 'Roboto',
			'variant'        => '400',
			'font-size'      => '15px',
			'line-height'    => '1.75',
			'letter-spacing' => '0',
			'color'          => '#262626',
			'text-transform' => 'normal',
            'subsets' => array( 'latin-ext' ),
		),
		'priority'    => 5,
		'output'      => array(
			array(
				'element' => array(
					'.single-post .post .chromium-dir-post-inner .entry-content',

				),
			),
		),
	) );


	// blog typography end


	// post typography start
	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'typography',
		'settings'    => 'post_title',
		'label'       => esc_html__( 'Post Titles', 'chromium-dir' ),
		'description' => esc_attr__( 'Post title on single post page.', 'chromium-dir' ),
		'section'     => 'typography',
		'default'     => array(
			'font-family'    => 'Roboto',
			'variant'        => '600',
			'font-size'      => '32px',
			'line-height'    => '1.3',
			'letter-spacing' => '0',
			'color'          => '#262626',
			'text-transform' => 'none',
            'subsets' => array( 'latin-ext' ),
		),
		'priority'    => 5,
		'output'      => array(
			array(
				'element' => array(
					'body.single-post #content .entry-header .entry-title',
                    'body.single-post .entry-title',
                    'body.page .entry-title'
				),
			),
		),
	) );
	// post typography end

	// product listing typography start
	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'typography',
		'settings'    => 'product_listing_titles',
		'label'       => esc_html__( 'Product Titles on product listing page', 'chromium-dir' ),
		'section'     => 'typography',
		'default'     => array(
			'font-family'    => 'Roboto',
			'variant'        => '500',
			'font-size'      => '1em',
			'line-height'    => '1.3',
			'letter-spacing' => '0',
			'color'          => '#000000',
			'text-transform' => 'none',
			'text-align'     => 'left',
            'subsets' => array( 'latin-ext' ),
		),
		'priority'    => 5,
		'output'      => array(
			array(
				'element' => array(
					'.products .product .woocommerce-loop-product__title',
                    '.woocommerce-grouped-product-list-item__label label a'
				),
			),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'typography',
		'settings'    => 'product_listing_prices',
		'label'       => esc_html__( 'Product price on product listing page', 'chromium-dir' ),
		'section'     => 'typography',
		'default'     => array(
			'font-family'    => 'Roboto',
			'variant'        => '600',
			'font-size'      => '15px',
			'line-height'    => '1.5',
			'letter-spacing' => '0',
			'color'          => '#3248a8',
			'text-transform' => 'none',
			'text-align'     => 'left',
            'subsets' => array( 'latin-ext' ),
		),
		'priority'    => 5,
		'output'      => array(
			array(
				'element' => array(
					'ul.products .product .price',
                    '.woocommerce-grouped-product-list-item__price .amount'
				),
			),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'color',
		'settings'    => 'rating_color',
		'label'       => esc_html__( 'Ratings Color', 'chromium-dir' ),
		'description' => esc_attr__( 'Star ratings color on listing page', 'chromium-dir' ),
		'section'     => 'typography',
		'default'     => '#00d1b7',
		'choices'     => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => array(
					'.star-rating',
					'.comment-form-rating .stars a:before',
					'.comment-form-rating .stars:hover a:before',
					'.comment-form-rating .stars:visited a:before',
					'.comment-form-rating .stars:active a:before',
					'.comment-form-rating .stars.selected a.active:before'
				),
				'property' => 'color',
			),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'typography',
		'settings'    => 'product_listing_button',
		'label'       => esc_html__( 'Add to cart button on product listing page', 'chromium-dir' ),
		'section'     => 'typography',
		'default'     => array(
			'font-family'    => 'Roboto',
			'variant'        => 'normal',
			'font-size'      => '1em',
			'line-height'    => '1.5',
			'letter-spacing' => '0',
			'color'          => '#000000',
			'text-transform' => 'none',
			'text-align'     => 'left',
            'subsets' => array( 'latin-ext' ),
		),
		'priority'    => 5,
		'output'      => array(
			array(
				'element' => array(
					'.products > .product .add_to_cart_button',
				),
			),
		),
	) );
	// product listing typography end


// Typography End


// Header Layout Start
	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'radio-image',
		'settings'    => 'logo_position',
		'label'       => esc_html__( 'Logo Position', 'chromium-dir' ),
		'description' => esc_attr__( 'Select how you want to position your logo, left, right or centered' , 'chromium-dir' ),
		'section'     => 'header',
		'default'     => 'center',
		'priority'    => 1,
		'choices'     => array(
			'left'   => get_template_directory_uri() . '/assets/img/logo_l.jpg',
			'right'  => get_template_directory_uri() . '/assets/img/logo_r.jpg',
			'center' => get_template_directory_uri() . '/assets/img/logo_c.jpg',
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'radio-image',
		'settings'    => 'menu_alignment',
		'label'       => esc_html__( 'Menu Items Alignment', 'chromium-dir' ),
		'description' => esc_attr__( 'Select how you want to align main menu items, left, right or centered' , 'chromium-dir' ),
		'section'     => 'header',
		'default'     => 'center',
		'priority'    => 3,
		'choices'     => array(
			'left'   => get_template_directory_uri() . '/assets/img/text-l.svg',
			'right'  => get_template_directory_uri() . '/assets/img/text-r.svg',
			'center' => get_template_directory_uri() . '/assets/img/text-c.svg',
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'switch',
		'settings'    => 'top_header_widget_area',
		'label'       => esc_html__( 'Top Header widget area', 'chromium-dir' ),
		'description' => esc_attr__( 'Enable or disable Top Header widget area.', 'chromium-dir' ),
		'section'     => 'header',
		'default'     => true,
		'priority'    => 5,
		'choices'     => array(
			'enabled'  => esc_attr__( 'Enabled', 'chromium-dir' ),
			'disabled'   => esc_attr__( 'Disables', 'chromium-dir' ),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'color',
		'settings'    => 'top_header_background_color',
		'label'       => esc_html__( 'Top Header Background', 'chromium-dir' ),
		'description' => esc_attr__( 'Top Header Background color.', 'chromium-dir' ),
		'section'     => 'header',
		'priority'    => 5,
		'active_callback' => array(
			array(
				'setting' => 'top_header_widget_area',
				'operator' => '==',
				'value' => true,
			)
		),
		'default'     => '#f6f6f6',
		'choices'     => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '.top-header-container',
				'property' => 'background-color',
			),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'color',
		'settings'    => 'top_header_text_color',
		'label'       => esc_html__( 'Top Header Color', 'chromium-dir' ),
		'description' => esc_attr__( 'Top Header text color.', 'chromium-dir' ),
		'section'     => 'header',
		'priority'    => 5,
		'default'     => '#ffffff',
		'active_callback' => array(
			array(
				'setting' => 'top_header_widget_area',
				'operator' => '==',
				'value' => true,
			)
		),
		'output'   => array(
			array(
				'element'  => '.top-header-container .top-header-inner',
				'property' => 'color',
			),
		),
	) );


	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'switch',
		'settings'    => 'pre_header_widget_area',
		'label'       => esc_html__( 'Pre Logo widget area', 'chromium-dir' ),
		'description' => esc_attr__( 'Enable or disable Pre Logo widget area.', 'chromium-dir' ),
		'section'     => 'header',
		'default'     => true,
		'priority'    => 5,
		'choices'     => array(
			'enabled'  => esc_attr__( 'Enabled', 'chromium-dir' ),
			'disabled'   => esc_attr__( 'Disables', 'chromium-dir' ),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'switch',
		'settings'    => 'post_header_widget_area',
		'label'       => esc_html__( 'Post Logo widget area', 'chromium-dir' ),
		'description' => esc_attr__( 'Enable or disable Post Logo widget area.', 'chromium-dir' ),
		'section'     => 'header',
		'default'     => true,
		'priority'    => 6,
		'choices'     => array(
			'enabled'  => esc_attr__( 'Enabled', 'chromium-dir' ),
			'disabled'   => esc_attr__( 'Disables', 'chromium-dir' ),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'switch',
		'settings'    => 'sticky_header',
		'label'       => esc_html__( 'Sticky Header', 'chromium-dir' ),
		'description' => esc_attr__( 'Enable or disable sticky header', 'chromium-dir' ),
		'section'     => 'header',
		'default'     => 'disabled',
		'priority'    => 7,
		'choices'     => array(
			'enabled'  => esc_attr__( 'Enabled', 'chromium-dir' ),
			'disabled'   => esc_attr__( 'Disables', 'chromium-dir' ),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'switch',
		'settings'    => 'header_elementor',
		'label'       => esc_html__( 'Elementor Header', 'chromium-dir' ),
		'description' => esc_attr__( 'Enable or disable Elementor template to show instead of default WordPress header', 'chromium-dir' ),
		'section'     => 'header',
		'default'     => false,
		'priority'    => 7,
		'choices'     => array(
			'enabled'  => esc_attr__( 'Enabled', 'chromium-dir' ),
			'disabled'   => esc_attr__( 'Disables', 'chromium-dir' ),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'switch',
		'settings'    => 'header_elementor_home',
		'label'       => esc_html__( 'Set different header for home page', 'chromium-dir' ),
		'description' => esc_attr__( 'Enable if you wish to set a custom header for home page.', 'chromium-dir' ),
		'section'     => 'header',
		'default'     => false,
		'priority'    => 8,
		'choices'     => array(
			'enabled'  => esc_attr__( 'Enabled', 'chromium-dir' ),
			'disabled'   => esc_attr__( 'Disabled', 'chromium-dir' ),
		),
		'active_callback' => array(
			array(
				'setting' => 'header_elementor',
				'operator' => '==',
				'value' => true,
			)
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'select',
		'settings'    => 'header_elementor_home_id',
		'label'       => esc_html__( 'Available Headers', 'chromium-dir' ),
		'section'     => 'header',
		'default'     => '',
		'active_callback' => array(
			array(
				'setting' => 'header_elementor_home',
				'operator' => '==',
				'value' => true,
			)
		),
		'choices'     => Chromium_Dir_Controller::get_available_headers(),
	) );

// Header Layout End

// Sidebar Layout Start
	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'radio-image',
		'settings'    => 'blog_page_layout',
		'label'       => esc_html__( 'Blog Page Sidebar Position', 'chromium-dir' ),
		'description' => esc_attr__('Select how you want to position your sidebar, left, right or no sidebar on the blog page' , 'chromium-dir' ),
		'section'     => 'layout',
		'default'     => 'right',
		'priority'    => 1,
		'choices'     => array(
			'left'   => get_template_directory_uri() . '/assets/img/two-col-left.png',
			'right'  => get_template_directory_uri() . '/assets/img/two-col-right.png',
			'no'     => get_template_directory_uri() . '/assets/img/one-col.png',
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'radio-image',
		'settings'    => 'post_page_layout',
		'label'       => esc_html__( 'Single Post Sidebar Position', 'chromium-dir' ),
		'description' => esc_attr__('Select how you want to position your sidebar, left, right or no sidebar on the post page' , 'chromium-dir' ),
		'section'     => 'layout',
		'default'     => 'right',
		'priority'    => 1,
		'choices'     => array(
			'left'   => get_template_directory_uri() . '/assets/img/two-col-left.png',
			'right'  => get_template_directory_uri() . '/assets/img/two-col-right.png',
			'no'     => get_template_directory_uri() . '/assets/img/one-col.png',
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'radio-image',
		'settings'    => 'search_page_layout',
		'label'       => esc_html__( 'Search Results Page Sidebar Position', 'chromium-dir' ),
		'description' => esc_attr__('Select how you want to position your sidebar, left, right or no sidebar on the search page' , 'chromium-dir'),
		'section'     => 'layout',
		'default'     => 'right',
		'priority'    => 1,
		'choices'     => array(
			'left'   => get_template_directory_uri() . '/assets/img/two-col-left.png',
			'right'  => get_template_directory_uri() . '/assets/img/two-col-right.png',
			'no'     => get_template_directory_uri() . '/assets/img/one-col.png',
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'radio-image',
		'settings'    => 'static_page_layout',
		'label'       => esc_html__( 'Static Page Sidebar Position', 'chromium-dir' ),
		'description' => esc_attr__('Select how you want to position your sidebar, left, right or no sidebar on the static page' , 'chromium-dir'),
		'section'     => 'layout',
		'default'     => 'right',
		'priority'    => 1,
		'choices'     => array(
			'left'   => get_template_directory_uri() . '/assets/img/two-col-left.png',
			'right'  => get_template_directory_uri() . '/assets/img/two-col-right.png',
			'no'     => get_template_directory_uri() . '/assets/img/one-col.png',
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'radio-image',
		'settings'    => 'shop_page_layout',
		'label'       => esc_html__( 'Shop Page Sidebar Position', 'chromium-dir' ),
		'description' => esc_attr__('Select how you want to position your sidebar, left, right or no sidebar on the shop page', 'chromium-dir'),
		'section'     => 'layout',
		'default'     => 'left',
		'priority'    => 1,
		'choices'     => array(
			'left'   => get_template_directory_uri() . '/assets/img/two-col-left.png',
			'right'  => get_template_directory_uri() . '/assets/img/two-col-right.png',
			'no'     => get_template_directory_uri() . '/assets/img/one-col.png',
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'radio-image',
		'settings'    => 'cart_page_layout',
		'label'       => esc_html__( 'Cart Page Sidebar Position', 'chromium-dir' ),
		'description' => esc_attr__('Select how you want to position your sidebar, left, right or no sidebar on the cart page', 'chromium-dir'),
		'section'     => 'layout',
		'default'     => 'no',
		'priority'    => 1,
		'choices'     => array(
			'left'   => get_template_directory_uri() . '/assets/img/two-col-left.png',
			'right'  => get_template_directory_uri() . '/assets/img/two-col-right.png',
			'no'     => get_template_directory_uri() . '/assets/img/one-col.png',
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'radio-image',
		'settings'    => 'checkout_page_layout',
		'label'       => esc_html__( 'Checkout Page Sidebar Position', 'chromium-dir' ),
		'description' => esc_attr__('Select how you want to position your sidebar, left, right or no sidebar on the checkout page', 'chromium-dir'),
		'section'     => 'layout',
		'default'     => 'no',
		'priority'    => 1,
		'choices'     => array(
			'left'   => get_template_directory_uri() . '/assets/img/two-col-left.png',
			'right'  => get_template_directory_uri() . '/assets/img/two-col-right.png',
			'no'     => get_template_directory_uri() . '/assets/img/one-col.png',
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'radio-image',
		'settings'    => 'product_page_layout',
		'label'       => esc_html__( 'Product Page Sidebar Position', 'chromium-dir' ),
		'description' => esc_attr__('Select how you want to position your sidebar, left, right or no sidebar on the product page', 'chromium-dir'),
		'section'     => 'layout',
		'default'     => 'no',
		'priority'    => 1,
		'choices'     => array(
			'left'   => get_template_directory_uri() . '/assets/img/two-col-left.png',
			'right'  => get_template_directory_uri() . '/assets/img/two-col-right.png',
			'no'     => get_template_directory_uri() . '/assets/img/one-col.png',
		),
	) );


// Sidebar Layout End

// Footer Layout Start

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'switch',
		'settings'    => 'footer_sidebar',
		'label'       => esc_html__( 'Show / Hide Footer Sidebar Section', 'chromium-dir' ),
		'description' => esc_attr__( 'Show or Hide Footer Sidebar Section (Once disabled widgets will be removed from the sidebar)', 'chromium-dir' ),
		'section'     => 'footer',
		'default'     => false,
		'priority'    => 1,
		'choices'     => array(
			'on'  => esc_attr__( 'Show', 'chromium-dir' ),
			'off' => esc_attr__( 'Hide', 'chromium-dir' ),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'switch',
		'settings'    => 'footer_sign',
		'label'       => esc_html__( 'Show / Hide Footer Signature', 'chromium-dir' ),
		'description' => esc_attr__( 'Show or Hide Footer Signature', 'chromium-dir' ),
		'section'     => 'footer',
		'default'     => false,
		'priority'    => 1,
		'choices'     => array(
			'on'  => esc_attr__( 'Hide', 'chromium-dir' ),
			'off' => esc_attr__( 'Show', 'chromium-dir' ),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'switch',
		'settings'    => 'footer_elementor',
		'label'       => esc_html__( 'Enable / Disable Footer Elementor Section', 'chromium-dir' ),
		'description' => esc_attr__( 'Enable or disable Footer Elementor Section in your footer, allows to show elementor templates in footer', 'chromium-dir' ),
		'section'     => 'footer',
		'default'     => true,
		'priority'    => 1,
		'choices'     => array(
			'on'  => esc_attr__( 'Enable', 'chromium-dir' ),
			'off' => esc_attr__( 'Disable', 'chromium-dir' ),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'color',
		'settings'    => 'footer_sidebar_background_color',
		'label'       => esc_html__( 'Links color', 'chromium-dir' ),
		'description' => esc_attr__( 'Color for links site-wide.', 'chromium-dir' ),
		'section'     => 'footer',
		'default'     => '#ffffff',
		'choices'     => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => 'chromium-dir-footer-widget-area',
				'property' => 'background-color',
			),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'     => 'textarea',
		'settings' => 'footer_copyright_text',
		'label'    => esc_html__( 'Footer Copyright Text', 'chromium-dir' ),
		'section'  => 'footer',
		'default'  => '',
		'priority' => 10,
	) );

// Footer Layout End

// Blog Layout Start
	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'radio',
		'settings'    => 'blog_posts_layout',
		'label'       => esc_html__( 'Blog Posts View', 'chromium-dir' ),
		'description' => esc_attr__('Select how you want your blog posts to be displayed, list or grid view.', 'chromium-dir'),
		'section'     => 'blog',
		'default'     => 'list',
		'priority'    => 1,
		'choices'     => array(
			'list'   => array(
				esc_attr__( 'List', 'chromium-dir' ),
				esc_attr__( 'Blog posts will follow one another as a list of posts', 'chromium-dir' ),
			),
			'grid' => array(
				esc_attr__( 'Grid', 'chromium-dir' ),
				esc_attr__( 'Blog posts will be laid out in a grid manner', 'chromium-dir' ),
			),
		),
	) );

    /*Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
        'type'        => 'radio',
        'settings'    => 'blog_posts_style',
        'label'       => esc_html__( 'Blog Posts Style', 'chromium-dir' ),
        'description' => esc_attr__('Select how you want your blog posts to be displayed, list or grid view.', 'chromium-dir'),
        'section'     => 'blog',
        'default'     => 'classy',
        'priority'    => 1,
        'choices'     => array(
            'simple'   => array(
                esc_attr__( 'Simple', 'chromium-dir' ),
                esc_attr__( 'Simple, clean blog post view.', 'chromium-dir' ),
            ),
            'decorated' => array(
                esc_attr__( 'Decorated', 'chromium-dir' ),
                esc_attr__( 'Decorated blog post view', 'chromium-dir' ),
            ),
            'classy' => array(
                esc_attr__( 'Classy', 'chromium-dir' ),
                esc_attr__( 'Classic blog post view', 'chromium-dir' ),
            ),
        ),
    ) );*/

    Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
        'type'        => 'radio-image',
        'settings'    => 'blog_post_heading_align',
        'label'       => esc_html__( 'Blog posts heading alignment', 'chromium-dir' ),
        'description' => esc_attr__( 'Set heading alignment on the blog posts' , 'chromium-dir' ),
        'section'     => 'blog',
        'default'     => 'left',
        'priority'    => 1,
        'choices'     => array(
            'left'   => get_template_directory_uri() . '/assets/img/text-l.svg',
            'right'  => get_template_directory_uri() . '/assets/img/text-r.svg',
            'center' => get_template_directory_uri() . '/assets/img/text-c.svg',
        ),
    ) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'radio-image',
		'settings'    => 'blog_post_content_align',
		'label'       => esc_html__( 'Blog posts content alignment', 'chromium-dir' ),
		'description' => esc_attr__( 'Set content alignment on the blog posts' , 'chromium-dir' ),
		'section'     => 'blog',
		'default'     => 'left',
		'priority'    => 1,
		'choices'     => array(
			'left'   => get_template_directory_uri() . '/assets/img/text-l.svg',
			'right'  => get_template_directory_uri() . '/assets/img/text-r.svg',
			'center' => get_template_directory_uri() . '/assets/img/text-c.svg',
		),
	) );


	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'number',
		'settings'    => 'posts_per_row',
		'label'       => esc_html__( 'Set the number of posts per row', 'chromium-dir' ),
		'description' => esc_attr__( 'Set the number of posts you want to show per row for posts grid view', 'chromium-dir' ),
		'section'     => 'blog',
		'active_callback' => array(
			array(
				'setting' => 'blog_posts_layout',
				'operator' => '==',
				'value' =>  'grid',
			)
		),
		'default'     => 2,
		'priority'    => 2,
		'choices'     => array(
			'min'  => 2,
			'max'  => 4,
			'step' => 1,
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'radio',
		'settings'    => 'blog_grid_layout',
		'label'       => esc_html__( 'Blog Grid View', 'chromium-dir' ),
		'description' => esc_attr__('Select how you want your blog posts to be displayed in grid view, masonry or fit a row.', 'chromium-dir' ),
		'section'     => 'blog',
		'default'     => 'masonry',
		'priority'    => 3,
		'active_callback' => array(
			array(
				'setting' => 'blog_posts_layout',
				'operator' => '==',
				'value' =>  'grid',
			)
		),
		'choices'     => array(
			'masonry'   => array(
				esc_html__( 'Masonry', 'chromium-dir' ),
                esc_html__( 'Blog will be placed by shuffle script in masonry layout', 'chromium-dir' ),
			),
			'simple' => array(
                esc_html__( 'Simple', 'chromium-dir' ),
                esc_html__( 'Blog posts will be laid out in a grid manner fitting the row', 'chromium-dir' ),
			),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'radio',
		'settings'    => 'blog_pagination',
		'label'       => esc_html__( 'Blog Navigation Style', 'chromium-dir' ),
		'description' => esc_attr__('Select the type of navigation on blog page, paginated or newer/older posts links.', 'chromium-dir' ),
		'section'     => 'blog',
		'default'     => 'paginated',
		'priority'    => 3,
		'choices'     => array(
			'paginated'   => array(
                esc_html__( 'Paginated', 'chromium-dir' ),
                esc_html__( 'Linked page numbers.', 'chromium-dir' ),
			),
			'linked' => array(
                esc_html__( 'Linked', 'chromium-dir' ),
                esc_html__( 'Newer and Older posts links', 'chromium-dir' ),
			),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'image',
		'settings'    => 'blog_page_banner',
		'label'       => esc_html__( 'Blog Page Banner', 'chromium-dir' ),
		'description' => esc_attr__( 'Set a banner that appears on blog page.', 'chromium-dir' ),
		'section'     => 'blog',
		'default'     => '',
		'choices'     => array(
			'save_as' => 'id',
		),
	) );

// Blog Layout End

// Post Layout Start

    Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
        'type'        => 'radio-image',
        'settings'    => 'post_heading_align',
        'label'       => esc_html__( 'Posts heading alignment', 'chromium-dir' ),
        'description' => esc_attr__( 'Set heading alignment on the single posts' , 'chromium-dir' ),
        'section'     => 'post',
        'default'     => 'left',
        'priority'    => 1,
        'choices'     => array(
            'left'   => get_template_directory_uri() . '/assets/img/text-l.svg',
            'right'  => get_template_directory_uri() . '/assets/img/text-r.svg',
            'center' => get_template_directory_uri() . '/assets/img/text-c.svg',
        ),
    ) );

    Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
        'type'        => 'radio-image',
        'settings'    => 'post_content_align',
        'label'       => esc_html__( 'Posts content alignment', 'chromium-dir' ),
        'description' => esc_attr__( 'Set content alignment on the single posts' , 'chromium-dir' ),
        'section'     => 'post',
        'default'     => 'left',
        'priority'    => 1,
        'choices'     => array(
            'left'   => get_template_directory_uri() . '/assets/img/text-l.svg',
            'right'  => get_template_directory_uri() . '/assets/img/text-r.svg',
            'center' => get_template_directory_uri() . '/assets/img/text-c.svg',
        ),
    ) );

    Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
        'type'        => 'radio',
        'settings'    => 'post_layout',
        'label'       => esc_html__( 'Single Posts Style', 'chromium-dir' ),
        'description' => esc_attr__('Select the design of your single post page', 'chromium-dir'),
        'section'     => 'post',
        'default'     => 'simple',
        'priority'    => 1,
        'choices'     => array(
            'simple'   => array(
                esc_html__( 'Simple', 'chromium-dir' ),
                esc_html__( 'Simple, clean blog post view.', 'chromium-dir' ),
            ),
            'modern' => array(
                esc_html__( 'Modern', 'chromium-dir' ),
                esc_html__( 'Modern blog post view', 'chromium-dir' ),
            ),
        ),
    ) );

// Post Layout End

// Shop Layout Start
	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'number',
		'settings'    => 'products_per_row',
		'label'       => esc_html__( 'Set the number of products per row', 'chromium-dir' ),
		'description' => esc_attr__( 'Set the number of products you want to show per row on a product listing page', 'chromium-dir' ),
		'section'     => 'shop',
		'default'     => 3,
		'choices'     => array(
			'min'  => 2,
			'max'  => 5,
			'step' => 1,
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'number',
		'settings'    => 'products_per_page',
		'label'       => esc_html__( 'Set the number of products per page', 'chromium-dir' ),
		'description' => esc_attr__( 'Set the number of products you want to show per page on a product listing page', 'chromium-dir' ),
		'section'     => 'shop',
		'default'     => 12
	) );


	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'image',
		'settings'    => 'shop_page_banner',
		'label'       => esc_html__( 'Shop Page Banner', 'chromium-dir' ),
		'description' => esc_attr__( 'Set a banner that appears on shop page.', 'chromium-dir' ),
		'section'     => 'shop',
		'default'     => '',
		'choices'     => array(
			'save_as' => 'id',
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'radio-image',
		'settings'    => 'product_content_align',
		'label'       => esc_html__( 'Product content alignment', 'chromium-dir' ),
		'description' => esc_attr__( 'Set content alignment for products on product listing page.' , 'chromium-dir' ),
		'section'     => 'shop',
		'default'     => 'center',
		'priority'    => 1,
		'choices'     => array(
			'left'   => get_template_directory_uri() . '/assets/img/text-l.svg',
			'right'  => get_template_directory_uri() . '/assets/img/text-r.svg',
			'center' => get_template_directory_uri() . '/assets/img/text-c.svg',
		),
	) );

    Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
        'type'        => 'switch',
        'settings'    => 'product_listing_rating',
        'label'       => esc_html__( 'Show / Hide product listing rating', 'chromium-dir' ),
        'description' => esc_attr__( 'Show or hide rating stars on product cards', 'chromium-dir' ),
        'section'     => 'shop',
        'default'     => 'off',
        'priority'    => 1,
        'choices'     => array(
            'on'  => esc_html__( 'Show', 'chromium-dir' ),
            'off' => esc_html__( 'Hide', 'chromium-dir' ),
        ),
    ) );


// Shop Layout End

// Product Layout Start
	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'number',
		'settings'    => 'products_thumbnail_columns',
		'label'       => esc_html__( 'Set the number of thumbnail columns on a product page', 'chromium-dir' ),
		'description' => esc_attr__( 'Set the number of thumbnail columns you want to show per row on a single product page', 'chromium-dir' ),
		'section'     => 'product',
		'default'     => 3,
		'choices'     => array(
			'min'  => 2,
			'max'  => 4,
			'step' => 1,
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'number',
		'settings'    => 'related_products_per_page',
		'label'       => esc_html__( 'Set the number of related products on product page', 'chromium-dir' ),
		'description' => esc_attr__( 'Set the number of related products you want to show on a single product page', 'chromium-dir' ),
		'section'     => 'product',
		'default'     => 4,
		'choices'     => array(
			'min'  => 2,
			'max'  => 5,
			'step' => 1,
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'number',
		'settings'    => 'related_products_per_column',
		'label'       => esc_html__( 'Set the number of related products per column', 'chromium-dir' ),
		'description' => esc_attr__( 'Set the number of related products you want to show on a single product page', 'chromium-dir' ),
		'section'     => 'product',
		'default'     => 4,
		'choices'     => array(
			'min'  => 2,
			'max'  => 5,
			'step' => 1,
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'image',
		'settings'    => 'product_page_banner',
		'label'       => esc_html__( 'Product Page Banner', 'chromium-dir' ),
		'description' => esc_attr__( 'Set a banner that appears on product page.', 'chromium-dir' ),
		'section'     => 'product',
		'default'     => '',
		'choices'     => array(
			'save_as' => 'id',
		),
	) );

	// single product typography start
	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'typography',
		'settings'    => 'single_product_title',
		'label'       => esc_html__( 'Single Product page title', 'chromium-dir' ),
		'section'     => 'product',
		'default'     => array(
			'font-family'    => 'Roboto',
			'variant'        => '500',
			'font-size'      => '32px',
			'line-height'    => '1.3',
			'letter-spacing' => '0',
			'color'          => '#000000',
			'text-transform' => 'none',
			'text-align'     => 'left'
		),
		'priority'    => 5,
		'output'      => array(
			array(
				'element' => array(
					'.single-product .product .summary .product_title',
				),
			),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'color',
		'settings'    => 'single_rating_color',
		'label'       => esc_html__( 'Single product ratings color', 'chromium-dir' ),
		'description' => esc_attr__( 'Star ratings color on products page', 'chromium-dir' ),
		'section'     => 'product',
		'default'     => '#00d1b7',
		'choices'     => array(
			'alpha' => true,
		),
		'output'   => array(
			array(
				'element'  => '.single-product .product .summary .star-rating',
				'property' => 'color',
			),
		),
	) );

	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'typography',
		'settings'    => 'single_product_price',
		'label'       => esc_html__( 'Single Product Price', 'chromium-dir' ),
		'section'     => 'product',
		'default'     => array(
			'font-family'    => 'Roboto',
			'variant'        => '500',
			'font-size'      => '1.25em',
			'line-height'    => '1.5',
			'letter-spacing' => '0',
			'color'          => '#000000',
			'text-transform' => 'none',
			'text-align'     => 'left'
		),
		'priority'    => 5,
		'output'      => array(
			array(
				'element' => array(
					'.single-product .product .summary .price',
				),
			),
		),
	) );


	Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
		'type'        => 'color',
		'settings'    => 'single_product_add_to_cart_button',
		'label'       => esc_html__( 'Single Product Add to Cart button', 'chromium-dir' ),
		'description' => esc_attr__( 'Background color for add to cart button on single product page', 'chromium-dir' ),
		'section'     => 'product',
		'default'     => '#000000',
		'output'   => array(
			array(
				'element'  => array(
					'.single-product .product .summary .single_add_to_cart_button',
					'.single-product .single-product-reviews .review-button-cont .button'
				),
				'property' => 'background-color',
			),
		),
	) );

	// single product typography end

// Product Layout End

// Listings Layout Start

    Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
        'type'        => 'image',
        'settings'    => 'listings_page_banner',
        'label'       => esc_html__( 'Listings Page Banner', 'chromium-dir' ),
        'description' => esc_attr__( 'Set a banner that appears on listings page.', 'chromium-dir' ),
        'section'     => 'listings',
        'default'     => '',
        'choices'     => array(
            'save_as' => 'id',
        ),
    ) );

    Chromium_Dir_Kirki_Customizer::add_field( 'chromium_dir_theme', array(
        'type'        => 'switch',
        'settings'    => 'listing_item_description',
        'label'       => esc_html__( 'Show / Hide listing description', 'chromium-dir' ),
        'description' => esc_attr__( 'Show or hide description field on listing', 'chromium-dir' ),
        'section'     => 'shop',
        'default'     => 'off',
        'priority'    => 1,
        'choices'     => array(
            'on'  => esc_html__( 'Show', 'chromium-dir' ),
            'off' => esc_html__( 'Hide', 'chromium-dir' ),
        ),
    ) );

// Listings Layout end

endif; // Chromium_Dir_Kirki_Customizer Options End