<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package dici
 */

if ( ! function_exists( 'chromium_dir_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function chromium_dir_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

        $time_string = sprintf(
            $time_string,
            esc_attr( get_the_date( DATE_W3C ) ),
            esc_html( get_the_date() ),
            esc_attr( get_the_modified_date( DATE_W3C ) ),
            esc_html( get_the_modified_date() )
        );

		$posted_on = sprintf(
		/* translators: %s: post date. */
			esc_html_x( '%s ', 'post date', 'chromium-dir' ),
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);

		echo '<span class="posted-on">' . $posted_on . '</span>'; // WPCS: XSS OK.

	}
endif;

if ( !function_exists( 'chromium_dir_posted_on_decorated' ) ) :

    function chromium_dir_posted_on_decorated(){
        $time_string = '<time class="entry-date published updated" datetime="%1$s"><span>%2$s</span> %3$s</time>';
        if ( get_the_time( 'j M' ) !== get_the_modified_time( 'j M ' ) ) {
            $time_string = '<time class="entry-date published" datetime="%1$s"><span>%2$s</span> %3$s</time><time class="updated" datetime="%4$s"><span>%5$s</span> %6$s</time>';
        }

        $time_string = sprintf( $time_string,
            esc_attr( get_the_date( 'DATE_W3C' ) ),
            esc_html( get_the_date('j') ),
            esc_html( get_the_date('M') ),
            esc_attr( get_the_modified_date( 'DATE_W3C' ) ),
            esc_html( get_the_modified_date('j') ),
            esc_html( get_the_modified_date('M') )
        );

        $posted_on = sprintf(
        /* translators: %s: post date. */
            esc_html_x( '%s ', 'post date', 'chromium-dir' ),
            '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
        );

        echo '<span class="posted-on">' . $posted_on . '</span>'; // WPCS: XSS OK.
    }

endif;

if ( ! function_exists( 'chromium_dir_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function chromium_dir_posted_by() {
		$byline = sprintf(
		/* translators: %s: post author. */
			esc_html_x( 'by %s', 'post author', 'chromium-dir' ),
			'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
		);

        echo chromium_dir_get_avatar(get_the_author_meta( 'ID' ));
		echo '<span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.

	}
endif;

if ( ! function_exists( 'chromium_dir_entry_categories' ) )	 :
    function chromium_dir_entry_categories(){
	    if ( 'post' === get_post_type() ) {
		    /* translators: used between list items, there is a space after the comma */
		    $categories_list = get_the_category_list(esc_html__(' ', 'chromium-dir'));
		    if ($categories_list) {
			    /* translators: 1: list of categories. */
			    printf('<span class="cat-links">' . esc_html__('%1$s', 'chromium-dir') . '</span> ', $categories_list); // WPCS: XSS OK.
		    }
	    }
    }
endif;

if ( ! function_exists( 'chromium_dir_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function chromium_dir_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
            chromium_dir_posted_by();
			/* translators: used between list items, there is a space after the comma */
            chromium_dir_entry_tags();
		}

		edit_post_link(
			sprintf(
				wp_kses(
				/* translators: %s: Name of current post. Only visible to screen readers */
					'%1$s <span class="screen-reader-text">%2$s</span>',
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				esc_html__('Edit', 'chromium-dir'),
				get_the_title()
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;

if ( ! function_exists( 'chromium_dir_entry_tags' ) ) :

    function chromium_dir_entry_tags(){
        /* translators: used between list items, there is a space after the comma */

        $before_text = '<span>'.esc_html__('Tags','chromium-dir').'</span>:   #';
        $tags_list = get_the_tag_list( $before_text, esc_html_x( ', #', 'list item separator', 'chromium-dir' ) );
        if ( $tags_list ) {
            /* translators: 1: list of tags. */
            printf( '<span class="tags-links"> '. esc_html__( '%1$s', 'chromium-dir' ) . '</span>', $tags_list ); // WPCS: XSS OK.
        }
    }

endif;

if ( ! function_exists( 'chromium_dir_comment_link' ) ) :
    function chromium_dir_comment_link(){
	    if (  ! is_single() &&  ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		    echo '<span class="comments-link">';
		    comments_popup_link(
			    sprintf(
				    wp_kses(
				    /* translators: %s: post title */
					    '%1$s <span class="screen-reader-text">%2$s %3$s</span>',
					    array(
						    'span' => array(
							    'class' => array(),
						    ),
					    )
				    ),
                    esc_html__( 'Leave a Comment','chromium-dir'),
                    esc_html__('on', 'chromium-dir'),
				    get_the_title()
			    )
		    );
		    echo '</span>';
	    }
    }
endif;

if ( ! function_exists( 'chromium_dir_get_avatar' ) ) :
    function chromium_dir_get_avatar($id_or_email){
        return get_avatar($id_or_email);
    }
endif;

if ( ! function_exists( 'chromium_dir_post_thumbnail' ) ) :
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 */
	function chromium_dir_post_thumbnail() {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return;
		}

		if ( is_singular() ) :
			?>

            <div class="post-thumbnail">
				<?php the_post_thumbnail('chromium-dir-single-post-thumbnail'); ?>
            </div><!-- .post-thumbnail -->

		<?php else : ?>

            <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true">
				<?php
				the_post_thumbnail( Chromium_Dir_Controller::instance()->get_post_thumbnail_size(), array(
					'alt' => the_title_attribute( array(
						'echo' => false,
					) ),
				) );
				?>
            </a>

		<?php endif; // End is_singular().
	}
endif;